Module extism_runtime::sdk

source ·

Structs

Wraps host functions
ExtismVal holds the type and value of a function argument/return

Functions

Free a context
Create a new context
Remove all plugins from the registry
Returns a pointer to the memory of the currently running plugin NOTE: this should only be called from host functions.
Allocate a memory block in the currently running plugin NOTE: this should only be called from host functions.
Free an allocated memory block NOTE: this should only be called from host functions.
Get the length of an allocated block NOTE: this should only be called from host functions.
Get the error associated with a Context or Plugin, if plugin is -1 then the context error will be returned
Free an ExtismFunction
Create a new host function
Set log file and level
Call a function
Update plugin config values, this will merge with the existing values
Remove a plugin from the registry and free associated memory
Returns true if func_name exists
Create a new plugin with additional host functions
Get the length of a plugin’s output data
Get the length of a plugin’s output data
Update a plugin, keeping the existing ID
Get the Extism version string

Type Definitions

Host function signature

Unions

A union type for host function argument/return values