Function extism_runtime::sdk::extism_current_plugin_memory
source · Expand description
Returns a pointer to the memory of the currently running plugin NOTE: this should only be called from host functions.
Returns a pointer to the memory of the currently running plugin NOTE: this should only be called from host functions.