Struct extism_runtime::Context

source ·
pub struct Context {
    pub plugins: BTreeMap<PluginIndex, UnsafeCell<Plugin>>,
    pub error: Option<CString>,
    /* private fields */
}
A Context is used to store and manage plugins

Fields

plugins: BTreeMap<PluginIndex, UnsafeCell<Plugin>>

Plugin registry

error: Option<CString>

Error message

Implementations

Create a new context

Get the next valid plugin ID

Set the context error

Convenience function to set error and return the value passed as the final parameter

Get a plugin from the context

Remove a plugin from the context