pub struct PluginMemory {
    pub store: Store<Internal>,
    pub memory: Memory,
    pub live_blocks: BTreeMap<usize, usize>,
    pub free: Vec<MemoryBlock>,
    pub position: usize,
}
Handles memory for plugins

Fields

store: Store<Internal>memory: Memorylive_blocks: BTreeMap<usize, usize>free: Vec<MemoryBlock>position: usize

Implementations

Create memory for a plugin

Write slice to memory

Read slice from memory

Size of memory in bytes

Size of memory in pages

Reserve n bytes of memory

Allocate and copy data into the wasm memory

Free the block allocated at offset

Log entire memory as hexdump using the trace log level

Reset memory - clears free-list and live blocks and resets position

Get memory as a slice of bytes

Get memory as a mutable slice of bytes

Get bytes occupied by the provided memory handle

Get mutable bytes occupied by the provided memory handle

Get str occupied by the provided memory handle

Get mutable str occupied by the provided memory handle

Pointer to the provided memory handle

Get the length of the block starting at offs

Get the block at the specified offset