Val

Type Alias Val 

pub type Val = Val;

Aliased Type

pub enum Val {
    I32(i32),
    I64(i64),
    F32(u32),
    F64(u64),
    V128(u128),
    FuncRef(Option<Func>),
    ExternRef(Option<ExternRef>),
}

Variants



I32(i32)

A 32-bit integer



I64(i64)

A 64-bit integer



F32(u32)

A 32-bit float.

Note that the raw bits of the float are stored here, and you can use f32::from_bits to create an f32 value.



F64(u64)

A 64-bit float.

Note that the raw bits of the float are stored here, and you can use f64::from_bits to create an f64 value.



V128(u128)

A 128-bit number



FuncRef(Option<Func>)

A first-class reference to a WebAssembly function.

FuncRef(None) is the null function reference, created by ref.null func in Wasm.



ExternRef(Option<ExternRef>)

An externref value which can hold opaque data to the Wasm instance itself.

ExternRef(None) is the null external reference, created by ref.null extern in Wasm.