#[no_mangle]
pub unsafe extern "C" fn extism_plugin_update(
    ctx: *mut Context,
    index: PluginIndex,
    wasm: *const u8,
    wasm_size: Size,
    functions: *mut *const ExtismFunction,
    nfunctions: Size,
    with_wasi: bool
) -> bool
Update a plugin, keeping the existing ID

Similar to extism_plugin_new but takes an index argument to specify which plugin to update

Memory for this plugin will be reset upon update